JepScriptEngineFactory
Date: 2015-08-04

jep

## Class JepScriptEngineFactory

- java.lang.Object
- - jep.JepScriptEngineFactory

- All Implemented Interfaces:
    javax.script.ScriptEngineFactory

      public class JepScriptEngineFactory
      extends java.lang.Object
      implements javax.script.ScriptEngineFactory

  Implements `ScriptEngineFactory`

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `JepScriptEngineFactory()`

  - ### Method Summary

    Methods
    Modifier and Type | Method and Description
    --- | ---
    `java.lang.String` | `getEngineName()` Describe `getEngineName` method here.
    `java.lang.String` | `getEngineVersion()` Describe `getEngineVersion` method here.
    `java.util.List<java.lang.String>` | `getExtensions()` (non-Javadoc)
    `java.lang.String` | `getLanguageName()` Describe `getLanguageName` method here.
    `java.lang.String` | `getLanguageVersion()` Describe `getLanguageVersion` method here.
    `java.lang.String` | `getMethodCallSyntax(java.lang.String obj, java.lang.String m, java.lang.String[] args)` Describe `getMethodCallSyntax` method here.
    `java.util.List<java.lang.String>` | `getMimeTypes()` (non-Javadoc)
    `java.util.List<java.lang.String>` | `getNames()` (non-Javadoc)
    `java.lang.String` | `getOutputStatement(java.lang.String o)` Describe `getOutputStatement` method here.
    `java.lang.Object` | `getParameter(java.lang.String p)` Describe `getParameter` method here.
    `java.lang.String` | `getProgram(java.lang.String[] lines)` Describe `getProgram` method here.
    `javax.script.ScriptEngine` | `getScriptEngine()` Describe `getScriptEngine` method here.

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### JepScriptEngineFactory

          public JepScriptEngineFactory()

  - ### Method Detail

    - #### getEngineName

          public java.lang.String getEngineName()

      Describe `getEngineName` method here.
      Specified by:
        `getEngineName` in interface `javax.script.ScriptEngineFactory`
      Returns:
        a `String` value

    - #### getEngineVersion

          public java.lang.String getEngineVersion()

      Describe `getEngineVersion` method here.
      Specified by:
        `getEngineVersion` in interface `javax.script.ScriptEngineFactory`
      Returns:
        a `String` value

    - #### getExtensions

          public java.util.List<java.lang.String> getExtensions()

      (non-Javadoc)
      Specified by:
        `getExtensions` in interface `javax.script.ScriptEngineFactory`
      See Also:
        `ScriptEngineFactory.getExtensions()`

    - #### getLanguageName

          public java.lang.String getLanguageName()

      Describe `getLanguageName` method here.
      Specified by:
        `getLanguageName` in interface `javax.script.ScriptEngineFactory`
      Returns:
        a `String` value

    - #### getLanguageVersion

          public java.lang.String getLanguageVersion()

      Describe `getLanguageVersion` method here.
      Specified by:
        `getLanguageVersion` in interface `javax.script.ScriptEngineFactory`
      Returns:
        a `String` value

    - #### getMethodCallSyntax

          public java.lang.String getMethodCallSyntax(java.lang.String obj,
                                             java.lang.String m,
                                             java.lang.String[] args)

      Describe `getMethodCallSyntax` method here.
      Specified by:
        `getMethodCallSyntax` in interface `javax.script.ScriptEngineFactory`
      Parameters:
        `obj` - a `String` value
        `m` - a `String` value
        `args` - a `String[]` value
      Returns:
        a `String` value

    - #### getMimeTypes

          public java.util.List<java.lang.String> getMimeTypes()

      (non-Javadoc)
      Specified by:
        `getMimeTypes` in interface `javax.script.ScriptEngineFactory`
      See Also:
        `ScriptEngineFactory.getMimeTypes()`

    - #### getNames

          public java.util.List<java.lang.String> getNames()

      (non-Javadoc)
      Specified by:
        `getNames` in interface `javax.script.ScriptEngineFactory`
      See Also:
        `ScriptEngineFactory.getNames()`

    - #### getOutputStatement

          public java.lang.String getOutputStatement(java.lang.String o)

      Describe `getOutputStatement` method here.
      Specified by:
        `getOutputStatement` in interface `javax.script.ScriptEngineFactory`
      Parameters:
        `o` - a `String` value
      Returns:
        a `String` value

    - #### getParameter

          public java.lang.Object getParameter(java.lang.String p)

      Describe `getParameter` method here.
      Specified by:
        `getParameter` in interface `javax.script.ScriptEngineFactory`
      Parameters:
        `p` - a `String` value
      Returns:
        an `Object` value

    - #### getProgram

          public java.lang.String getProgram(java.lang.String[] lines)

      Describe `getProgram` method here.
      Specified by:
        `getProgram` in interface `javax.script.ScriptEngineFactory`
      Parameters:
        `lines` - a `String[]` value
      Returns:
        a `String` value

    - #### getScriptEngine

          public javax.script.ScriptEngine getScriptEngine()

      Describe `getScriptEngine` method here.
      Specified by:
        `getScriptEngine` in interface `javax.script.ScriptEngineFactory`
      Returns:
        a `ScriptEngine` value